/*
 * file CcConfigSpec.java
 *
 *
 * Licensed Materials - Property of IBM 
 * Restricted Materials of IBM  
 * 
 * com.ibm.rational.wvcm.stp.cc.CcConfigSpec
 * 
 * (C) Copyright IBM Corporation 2004, 2015.  All Rights Reserved. 
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or  
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp. 
 */

package com.ibm.rational.wvcm.stp.cc;

/**
 * <p>
 * The configuration specification ("config spec") for a ClearCase view.
 * A view's config spec determines which elements appear in a view,
 * and which version of each element is selected by the view.
 * For snapshot and web views, the config spec also determines which
 * files are loaded in the view.
 * </p>
 * <p> 
 * A ConfigSpec has two sections, one containing element rules
 * and one containing load rules. Methods are provided to manipulate
 * each of these sections.
 * </p>
 * <p>
 * CcView.getConfigSpec returns a ConfigSpec object.
 * Note that it is necessary to set the CONFIG_SPEC property on the 
 * desired view proxy and write that proxy's properties in order for 
 * this change to take effect.
 * </p>
 */
public interface CcConfigSpec
{
    /**
     * Returns the "Element Rules" section (everything except the load rules)
     * of the configuration specification.
     * 
     * @return the element rules as a single newline-separated string
     * Returns empty string if none.
     */
    public String getElementRules();
    
    /**
     * Returns the automatically-generated UCM section of the configuration
     * specification.
     * 
     * @return the UCM-generated element rules.
     * Returns empty string if none (i.e. if not a UCM view.)
     */
    public String getUcmElementRules();
    
    /**
     * Returns the load-rules section of a configuration specification.
     * 
     * @return the load-rules, as a single newline-separated string.
     * Returns empty string if none (i.e. if not a snapshot view or a web view).
     */
    public String getLoadRules();

    /**
     * Sets the "Element Rules" (everything except the load rules) section of a ConfigSpec object.
     * 
     * Config specs are manipulated through the property mechanism.
     * 
     * For automatic views, setForceAutomaticViewUpdateFlag must be set to true for
     * setElementRules to take effect
     *
     * @param elementRules a newline-separated string representing the new element rules
     */
    public void setElementRules(String elementRules);

    /**
     * If true (default), element rules and load rules are updated in the config spec.
     * If false, only load rules are updated in the config spec.
     * 
     * @param force
     */
    public void setForceAutomaticViewUpdateFlag(boolean force);
    
    /**
     * Sets the load-rules section of a configuration specification.
     * 
     * Config specs are manipulated through the property mechanism.
     * 
     * 
     * @param loadRules a newline-separated string representing the new load rules
     */
    public void setLoadRules(String loadRules);
    
    /**
     * Returns the configuration specification minus the auto generated UCM section, if any.
     * 
     * @return the configuration specification, as a single newline-separated string.
     */
    public String getCSpec();
    
    /**
     * Sets the configuration specification after adding the auto generated UCM
     * section, if any. Note that it is necessary to set the CONFIG_SPEC
     * property on the desired view proxy and write that proxy's properties in
     * order for this change to take effect.
     * 
     * @param cspec a newline-separated string representing the new load configuration specification
     */
    public void setCSpec(String cspec);
    
    /**
     * Returns the filtered load-rules section (i.e free from comments, if any) 
     * of a configuration specification.
     * 
     * @return the filtered load-rules, as a single newline-separated string.
     * Returns empty string if none (i.e. if not a snapshot view or a web view).
     */
    public String getLoadRulesNoComments();
}